@@ -828,7 +828,10 @@ def get_service_def_from_file(name, cluster_name):
 
     task_def = change_keys(task_def, convert=lowerCaseFirstLetter)
 
-    log_config = shared_config['LogConfiguration']
+    # Get log config but don't modify case. This ensures "options" are correct.
+    # Some values like "Name" for firelens config is uppercase but others are lowercase
+    # Hence leave options/secrets case as is.
+    log_config = change_keys(shared_config['LogConfiguration'], convert=lowerCaseFirstLetter, recursive=False)
 
     log_config = json.dumps(log_config)
 
@@ -841,7 +844,8 @@ def get_service_def_from_file(name, cluster_name):
     log_config = json.loads(log_config)
 
     for cd in task_def['containerDefinitions']:
-        cd['logConfiguration'] = log_config
+        if 'logConfiguration' not in cd:
+            cd['logConfiguration'] = log_config
 
     service_def['TaskDefinition'] = task_def
 
